summaryrefslogtreecommitdiffstats
path: root/examples/scatterchart
diff options
context:
space:
mode:
authorMiikka Heikkinen <miikka.heikkinen@digia.com>2013-08-09 08:29:55 +0300
committerMiikka Heikkinen <miikka.heikkinen@digia.com>2013-08-09 08:48:10 +0300
commitdde2aa073bc348b35b1148d3b25e914b4f9ce3d9 (patch)
treee3bd7f6d87d19dca4b938d136cd661caae69e325 /examples/scatterchart
parent44871935507e215c9d7881911a1c9ade81cf5770 (diff)
Changed "tick" to "segment"
Talking about tick count was misleading, since we are counting the segments between ticks instead of ticks themselves. Changed the term accordingly to reduce confusion. Change-Id: Ic044b179a950083ba9116173a424b865ebb5785a Reviewed-by: Tomi Korpipää <tomi.korpipaa@digia.com>
Diffstat (limited to 'examples/scatterchart')
-rw-r--r--examples/scatterchart/scatterchart.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/examples/scatterchart/scatterchart.cpp b/examples/scatterchart/scatterchart.cpp
index f2d3d50a..6a945bd4 100644
--- a/examples/scatterchart/scatterchart.cpp
+++ b/examples/scatterchart/scatterchart.cpp
@@ -79,8 +79,8 @@ void ScatterDataModifier::addData()
<< "other 0.0" << "other 0.2" << "other 0.4" << "other 0.6" << "other 0.8"
<< "other 1.0";
- // Set tick count and step
- m_chart->setTickCount(10, 0.1f, -1.0f);
+ // Set segment count and step
+ m_chart->setSegmentCount(10, 0.1f, -1.0f);
// Add labels
m_chart->rowAxis()->setTitle("Somethings");